@@ -4,8 +4,10 @@ import re
 import sys
 import unittest
 import warnings
+
 import h5py
 import numpy as np
+
 import meep as mp
 
 try:
@@ -16,11 +18,11 @@ except NameError:
 
 class TestSimulation(unittest.TestCase):
 
-    fname_base = re.sub(r'\.py$', '', os.path.split(sys.argv[0])[1])
-    fname = fname_base + '-ez-000200.00.h5'
+    fname_base = re.sub(r"\.py$", "", os.path.split(sys.argv[0])[1])
+    fname = fname_base + "-ez-000200.00.h5"
 
     def setUp(self):
-        print("Running {}".format(self._testMethodName))
+        print(f"Running {self._testMethodName}")
 
     @classmethod
     def setUpClass(cls):
@@ -33,16 +35,106 @@ class TestSimulation(unittest.TestCase):
     def test_interpolate_numbers(self):
 
         expected = [
-            1.0, 1.0909090909090908, 1.1818181818181819, 1.2727272727272727, 1.3636363636363635, 1.4545454545454546, 1.5454545454545454, 1.6363636363636365, 1.7272727272727273, 1.8181818181818181, 1.9090909090909092,
-            2.0, 2.090909090909091, 2.1818181818181817, 2.272727272727273, 2.3636363636363638, 2.4545454545454546, 2.5454545454545454, 2.6363636363636362, 2.727272727272727, 2.8181818181818183, 2.909090909090909,
-            3.0, 3.090909090909091, 3.1818181818181817, 3.272727272727273, 3.3636363636363638, 3.4545454545454546, 3.5454545454545454, 3.6363636363636362, 3.727272727272727, 3.8181818181818183, 3.909090909090909,
-            4.0, 4.090909090909091, 4.181818181818182, 4.2727272727272725, 4.363636363636363, 4.454545454545454, 4.545454545454546, 4.636363636363637, 4.7272727272727275, 4.818181818181818, 4.909090909090909,
-            5.0, 5.090909090909091, 5.181818181818182, 5.2727272727272725, 5.363636363636363, 5.454545454545454, 5.545454545454546, 5.636363636363637, 5.7272727272727275, 5.818181818181818, 5.909090909090909,
-            6.0, 6.090909090909091, 6.181818181818182, 6.2727272727272725, 6.363636363636363, 6.454545454545454, 6.545454545454546, 6.636363636363637, 6.7272727272727275, 6.818181818181818, 6.909090909090909,
-            7.0, 7.090909090909091, 7.181818181818182, 7.2727272727272725, 7.363636363636363, 7.454545454545454, 7.545454545454546, 7.636363636363637, 7.7272727272727275, 7.818181818181818, 7.909090909090909,
-            8.0, 8.090909090909092, 8.181818181818182, 8.272727272727273, 8.363636363636363, 8.454545454545455, 8.545454545454545, 8.636363636363637, 8.727272727272727, 8.818181818181818, 8.909090909090908,
-            9.0, 9.090909090909092, 9.181818181818182, 9.272727272727273, 9.363636363636363, 9.454545454545455, 9.545454545454545, 9.636363636363637, 9.727272727272727, 9.818181818181818, 9.909090909090908,
-            10.0
+            1.0,
+            1.0909090909090908,
+            1.1818181818181819,
+            1.2727272727272727,
+            1.3636363636363635,
+            1.4545454545454546,
+            1.5454545454545454,
+            1.6363636363636365,
+            1.7272727272727273,
+            1.8181818181818181,
+            1.9090909090909092,
+            2.0,
+            2.090909090909091,
+            2.1818181818181817,
+            2.272727272727273,
+            2.3636363636363638,
+            2.4545454545454546,
+            2.5454545454545454,
+            2.6363636363636362,
+            2.727272727272727,
+            2.8181818181818183,
+            2.909090909090909,
+            3.0,
+            3.090909090909091,
+            3.1818181818181817,
+            3.272727272727273,
+            3.3636363636363638,
+            3.4545454545454546,
+            3.5454545454545454,
+            3.6363636363636362,
+            3.727272727272727,
+            3.8181818181818183,
+            3.909090909090909,
+            4.0,
+            4.090909090909091,
+            4.181818181818182,
+            4.2727272727272725,
+            4.363636363636363,
+            4.454545454545454,
+            4.545454545454546,
+            4.636363636363637,
+            4.7272727272727275,
+            4.818181818181818,
+            4.909090909090909,
+            5.0,
+            5.090909090909091,
+            5.181818181818182,
+            5.2727272727272725,
+            5.363636363636363,
+            5.454545454545454,
+            5.545454545454546,
+            5.636363636363637,
+            5.7272727272727275,
+            5.818181818181818,
+            5.909090909090909,
+            6.0,
+            6.090909090909091,
+            6.181818181818182,
+            6.2727272727272725,
+            6.363636363636363,
+            6.454545454545454,
+            6.545454545454546,
+            6.636363636363637,
+            6.7272727272727275,
+            6.818181818181818,
+            6.909090909090909,
+            7.0,
+            7.090909090909091,
+            7.181818181818182,
+            7.2727272727272725,
+            7.363636363636363,
+            7.454545454545454,
+            7.545454545454546,
+            7.636363636363637,
+            7.7272727272727275,
+            7.818181818181818,
+            7.909090909090909,
+            8.0,
+            8.090909090909092,
+            8.181818181818182,
+            8.272727272727273,
+            8.363636363636363,
+            8.454545454545455,
+            8.545454545454545,
+            8.636363636363637,
+            8.727272727272727,
+            8.818181818181818,
+            8.909090909090908,
+            9.0,
+            9.090909090909092,
+            9.181818181818182,
+            9.272727272727273,
+            9.363636363636363,
+            9.454545454545455,
+            9.545454545454545,
+            9.636363636363637,
+            9.727272727272727,
+            9.818181818181818,
+            9.909090909090908,
+            10.0,
         ]
 
         nums = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
@@ -73,7 +165,7 @@ class TestSimulation(unittest.TestCase):
             mp.Vector3(0.42499999999999993),
             mp.Vector3(0.44999999999999996),
             mp.Vector3(0.475),
-            mp.Vector3(0.5)
+            mp.Vector3(0.5),
         ]
 
         res = mp.interpolate(19, [mp.Vector3(), mp.Vector3(0.5)])
@@ -94,7 +186,7 @@ class TestSimulation(unittest.TestCase):
             0.15240480961923594,
             0.15280561122244193,
             0.15320641282564793,
-            0.15360721442885392
+            0.15360721442885392,
         ]
 
         res = np.linspace(0.15, 0.15 + 0.000400801603206 * 10, num=10, endpoint=False)
@@ -112,17 +204,20 @@ class TestSimulation(unittest.TestCase):
         fcen = 1.0
         df = 1.0
 
-        sources = mp.Source(src=mp.GaussianSource(fcen, fwidth=df), center=mp.Vector3(),
-                            component=mp.Ez)
+        sources = mp.Source(
+            src=mp.GaussianSource(fcen, fwidth=df), center=mp.Vector3(), component=mp.Ez
+        )
 
         symmetries = [mp.Mirror(mp.X), mp.Mirror(mp.Y)]
 
-        return mp.Simulation(resolution=resolution,
-                             cell_size=cell,
-                             boundary_layers=[pml_layers],
-                             sources=[sources],
-                             symmetries=symmetries,
-                             **kwargs)
+        return mp.Simulation(
+            resolution=resolution,
+            cell_size=cell,
+            boundary_layers=[pml_layers],
+            sources=[sources],
+            symmetries=symmetries,
+            **kwargs,
+        )
 
     @unittest.skipIf(not mp.with_mpi(), "MPI specific test")
     def test_mpi(self):
@@ -130,7 +225,7 @@ class TestSimulation(unittest.TestCase):
 
     def test_use_output_directory_default(self):
         sim = self.init_simple_simulation()
-        output_dir = os.path.join(self.temp_dir, 'simulation-out')
+        output_dir = os.path.join(self.temp_dir, "simulation-out")
         sim.use_output_directory(output_dir)
         sim.run(mp.at_end(mp.output_efield_z), until=200)
 
@@ -141,8 +236,10 @@ class TestSimulation(unittest.TestCase):
         sim.use_output_directory(self.temp_dir)
         sim.run(mp.at_time(100, mp.output_efield_z), until=200)
 
-        fname = os.path.join(self.temp_dir,
-                             sim.get_filename_prefix() +  '-ez-000100.00.h5')
+        fname = os.path.join(
+            self.temp_dir, f"{sim.get_filename_prefix()}-ez-000100.00.h5"
+        )
+
         self.assertTrue(os.path.exists(fname))
 
     def test_after_sources_and_time(self):
@@ -160,10 +257,15 @@ class TestSimulation(unittest.TestCase):
     def test_with_prefix(self):
         sim = self.init_simple_simulation()
         sim.use_output_directory(self.temp_dir)
-        sim.run(mp.with_prefix('test_prefix-', mp.at_end(mp.output_efield_z)), until=200)
+        sim.run(
+            mp.with_prefix("test_prefix-", mp.at_end(mp.output_efield_z)), until=200
+        )
+
+        fname = os.path.join(
+            self.temp_dir,
+            (f"test_prefix-{sim.get_filename_prefix()}" + "-ez-000200.00.h5"),
+        )
 
-        fname = os.path.join(self.temp_dir, 'test_prefix-' + sim.get_filename_prefix() +
-                             '-ez-000200.00.h5')
         self.assertTrue(os.path.exists(fname))
 
     def test_extra_materials(self):
@@ -189,25 +291,29 @@ class TestSimulation(unittest.TestCase):
     def test_in_volume(self):
         sim = self.init_simple_simulation()
         sim.use_output_directory(self.temp_dir)
-        sim.filename_prefix = 'test_in_volume'
+        sim.filename_prefix = "test_in_volume"
         vol = mp.Volume(mp.Vector3(), size=mp.Vector3(x=2))
         sim.run(mp.at_end(mp.in_volume(vol, mp.output_efield_z)), until=200)
-        fn = os.path.join(self.temp_dir, 'test_in_volume-ez-000200.00.h5')
+        fn = os.path.join(self.temp_dir, "test_in_volume-ez-000200.00.h5")
         self.assertTrue(os.path.exists(fn))
 
     def test_in_point(self):
         sim = self.init_simple_simulation()
         sim.use_output_directory(self.temp_dir)
-        sim.filename_prefix = 'test_in_point'
+        sim.filename_prefix = "test_in_point"
         pt = mp.Vector3()
         sim.run(mp.at_end(mp.in_point(pt, mp.output_efield_z)), until=200)
-        fn = os.path.join(self.temp_dir, 'test_in_point-ez-000200.00.h5')
+        fn = os.path.join(self.temp_dir, "test_in_point-ez-000200.00.h5")
         self.assertTrue(os.path.exists(fn))
 
     def test_epsilon_input_file(self):
         sim = self.init_simple_simulation()
-        eps_input_fname = 'cyl-ellipsoid-eps-ref.h5'
-        eps_input_dir = os.path.abspath(os.path.join(os.path.dirname(os.path.abspath(__file__)), '..', '..', 'tests'))
+        eps_input_fname = "cyl-ellipsoid-eps-ref.h5"
+        eps_input_dir = os.path.abspath(
+            os.path.join(
+                os.path.dirname(os.path.abspath(__file__)), "..", "..", "tests"
+            )
+        )
         eps_input_path = os.path.join(eps_input_dir, eps_input_fname)
         sim.epsilon_input_file = eps_input_path
 
@@ -219,19 +325,25 @@ class TestSimulation(unittest.TestCase):
 
         # Test unicode file name for Python 2
         if sys.version_info[0] == 2:
-            sim = self.init_simple_simulation(epsilon_input_file=unicode(eps_input_path))
+            sim = self.init_simple_simulation(
+                epsilon_input_file=unicode(eps_input_path)
+            )
             sim.run(until=200)
             fp = sim.get_field_point(mp.Ez, mp.Vector3(x=1))
             self.assertAlmostEqual(fp, -0.002989654055823199)
 
     def test_numpy_epsilon(self):
         sim = self.init_simple_simulation()
-        eps_input_fname = 'cyl-ellipsoid-eps-ref.h5'
-        eps_input_dir = os.path.abspath(os.path.join(os.path.dirname(os.path.abspath(__file__)), '..', '..', 'tests'))
+        eps_input_fname = "cyl-ellipsoid-eps-ref.h5"
+        eps_input_dir = os.path.abspath(
+            os.path.join(
+                os.path.dirname(os.path.abspath(__file__)), "..", "..", "tests"
+            )
+        )
         eps_input_path = os.path.join(eps_input_dir, eps_input_fname)
 
-        with h5py.File(eps_input_path, 'r') as f:
-            sim.default_material = f['eps'][()]
+        with h5py.File(eps_input_path, "r") as f:
+            sim.default_material = f["eps"][()]
 
         sim.run(until=200)
         fp = sim.get_field_point(mp.Ez, mp.Vector3(x=1))
@@ -240,51 +352,68 @@ class TestSimulation(unittest.TestCase):
         self.assertAlmostEqual(fp, -0.002989654055823199, places=places)
 
     def test_set_materials(self):
-
         def change_geom(sim):
             t = sim.meep_time()
             fn = t * 0.02
-            geom = [mp.Cylinder(radius=3, material=mp.Medium(index=3.5), center=mp.Vector3(fn, fn)),
-                    mp.Ellipsoid(size=mp.Vector3(1, 2, mp.inf), center=mp.Vector3(fn, fn))]
+            geom = [
+                mp.Cylinder(
+                    radius=3, material=mp.Medium(index=3.5), center=mp.Vector3(fn, fn)
+                ),
+                mp.Ellipsoid(size=mp.Vector3(1, 2, mp.inf), center=mp.Vector3(fn, fn)),
+            ]
 
             sim.set_materials(geometry=geom)
 
         c = mp.Cylinder(radius=3, material=mp.Medium(index=3.5))
         e = mp.Ellipsoid(size=mp.Vector3(1, 2, mp.inf))
 
-        sources = mp.Source(src=mp.GaussianSource(1, fwidth=0.1), component=mp.Hz, center=mp.Vector3())
+        sources = mp.Source(
+            src=mp.GaussianSource(1, fwidth=0.1), component=mp.Hz, center=mp.Vector3()
+        )
         symmetries = [mp.Mirror(mp.X, -1), mp.Mirror(mp.Y, -1)]
 
-        sim = mp.Simulation(cell_size=mp.Vector3(10, 10),
-                            geometry=[c, e],
-                            boundary_layers=[mp.PML(1.0)],
-                            sources=[sources],
-                            symmetries=symmetries,
-                            resolution=16)
+        sim = mp.Simulation(
+            cell_size=mp.Vector3(10, 10),
+            geometry=[c, e],
+            boundary_layers=[mp.PML(1.0)],
+            sources=[sources],
+            symmetries=symmetries,
+            resolution=16,
+        )
 
-        eps = {'arr1': None, 'arr2': None}
+        eps = {"arr1": None, "arr2": None}
 
         def get_arr1(sim):
-            eps['arr1'] = sim.get_array(mp.Dielectric, mp.Volume(mp.Vector3(), mp.Vector3(10, 10)))
+            eps["arr1"] = sim.get_array(
+                mp.Dielectric, mp.Volume(mp.Vector3(), mp.Vector3(10, 10))
+            )
 
         def get_arr2(sim):
-            eps['arr2'] = sim.get_array(mp.Dielectric, mp.Volume(mp.Vector3(), mp.Vector3(10, 10)))
+            eps["arr2"] = sim.get_array(
+                mp.Dielectric, mp.Volume(mp.Vector3(), mp.Vector3(10, 10))
+            )
 
-        sim.run(mp.at_time(50, get_arr1), mp.at_time(100, change_geom),
-                mp.at_end(get_arr2), until=200)
+        sim.run(
+            mp.at_time(50, get_arr1),
+            mp.at_time(100, change_geom),
+            mp.at_end(get_arr2),
+            until=200,
+        )
 
-        self.assertFalse(np.array_equal(eps['arr1'], eps['arr2']))
+        self.assertFalse(np.array_equal(eps["arr1"], eps["arr2"]))
 
     def test_modal_volume_in_box(self):
         sim = self.init_simple_simulation()
         sim.run(until=200)
         vol = sim.fields.total_volume()
-        self.assertAlmostEqual(sim.fields.modal_volume_in_box(vol),
-                               sim.modal_volume_in_box())
+        self.assertAlmostEqual(
+            sim.fields.modal_volume_in_box(vol), sim.modal_volume_in_box()
+        )
 
         vol = mp.Volume(mp.Vector3(), size=mp.Vector3(1, 1, 1))
-        self.assertAlmostEqual(sim.fields.modal_volume_in_box(vol.swigobj),
-                               sim.modal_volume_in_box(vol))
+        self.assertAlmostEqual(
+            sim.fields.modal_volume_in_box(vol.swigobj), sim.modal_volume_in_box(vol)
+        )
 
     def test_in_box_volumes(self):
         sim = self.init_simple_simulation()
@@ -307,7 +436,7 @@ class TestSimulation(unittest.TestCase):
         sim.use_output_directory(self.temp_dir)
         sim.symmetries = []
         sim.geometry = [mp.Cylinder(0.2, material=mp.Medium(index=3))]
-        sim.filename_prefix = 'test_get_array_output'
+        sim.filename_prefix = "test_get_array_output"
         sim.run(until=20)
 
         mp.output_epsilon(sim)
@@ -320,21 +449,21 @@ class TestSimulation(unittest.TestCase):
         energy_arr = sim.get_tot_pwr(snap=True)
         efield_arr = sim.get_efield(snap=True)
 
-        fname_fmt = os.path.join(self.temp_dir, 'test_get_array_output-{}-000020.00.h5')
+        fname_fmt = os.path.join(self.temp_dir, "test_get_array_output-{}-000020.00.h5")
 
-        with h5py.File(fname_fmt.format('eps'), 'r') as f:
-            eps = f['eps'][()]
+        with h5py.File(fname_fmt.format("eps"), "r") as f:
+            eps = f["eps"][()]
 
-        with h5py.File(fname_fmt.format('ez'), 'r') as f:
-            efield_z = f['ez'][()]
+        with h5py.File(fname_fmt.format("ez"), "r") as f:
+            efield_z = f["ez"][()]
 
-        with h5py.File(fname_fmt.format('energy'), 'r') as f:
-            energy = f['energy'][()]
+        with h5py.File(fname_fmt.format("energy"), "r") as f:
+            energy = f["energy"][()]
 
-        with h5py.File(fname_fmt.format('e'), 'r') as f:
-            ex = f['ex'][()]
-            ey = f['ey'][()]
-            ez = f['ez'][()]
+        with h5py.File(fname_fmt.format("e"), "r") as f:
+            ex = f["ex"][()]
+            ey = f["ey"][()]
+            ez = f["ez"][()]
             efield = np.stack([ex, ey, ez], axis=-1)
 
         np.testing.assert_allclose(eps, eps_arr)
@@ -346,13 +475,21 @@ class TestSimulation(unittest.TestCase):
         # Issue 309
         cell = mp.Vector3(16, 8, 0)
 
-        geometry = [mp.Block(mp.Vector3(1e20, 1, 1e20),
-                             center=mp.Vector3(0, 0),
-                             material=mp.Medium(epsilon=12))]
+        geometry = [
+            mp.Block(
+                mp.Vector3(1e20, 1, 1e20),
+                center=mp.Vector3(0, 0),
+                material=mp.Medium(epsilon=12),
+            )
+        ]
 
-        sources = [mp.Source(mp.ContinuousSource(frequency=0.15),
-                             component=mp.Ez,
-                             center=mp.Vector3(-7, 0))]
+        sources = [
+            mp.Source(
+                mp.ContinuousSource(frequency=0.15),
+                component=mp.Ez,
+                center=mp.Vector3(-7, 0),
+            )
+        ]
 
         pml_layers = [mp.PML(1.0)]
         resolution = 10
@@ -362,14 +499,13 @@ class TestSimulation(unittest.TestCase):
             boundary_layers=pml_layers,
             geometry=geometry,
             sources=sources,
-            resolution=resolution
+            resolution=resolution,
         )
 
         sim.use_output_directory(self.temp_dir)
         sim.run(mp.synchronized_magnetic(mp.output_bfield_y), until=10)
 
     def test_harminv_warnings(self):
-
         def check_warnings(sim, h, should_warn=True):
             with warnings.catch_warnings(record=True) as w:
                 warnings.simplefilter("always")
@@ -381,21 +517,30 @@ class TestSimulation(unittest.TestCase):
                 else:
                     self.assertEqual(len(w), 0)
 
-        sources = [mp.Source(src=mp.GaussianSource(1, fwidth=1), center=mp.Vector3(), component=mp.Ez)]
-        sim = mp.Simulation(cell_size=mp.Vector3(10, 10), resolution=10, sources=sources)
+        sources = [
+            mp.Source(
+                src=mp.GaussianSource(1, fwidth=1), center=mp.Vector3(), component=mp.Ez
+            )
+        ]
+        sim = mp.Simulation(
+            cell_size=mp.Vector3(10, 10), resolution=10, sources=sources
+        )
         h = mp.Harminv(mp.Ez, mp.Vector3(), 1.4, 0.5)
         check_warnings(sim, h)
 
-        sim = mp.Simulation(cell_size=mp.Vector3(10, 10), resolution=10, sources=sources)
+        sim = mp.Simulation(
+            cell_size=mp.Vector3(10, 10), resolution=10, sources=sources
+        )
         h = mp.Harminv(mp.Ez, mp.Vector3(), 0.5, 0.5)
         check_warnings(sim, h)
 
-        sim = mp.Simulation(cell_size=mp.Vector3(10, 10), resolution=10, sources=sources)
+        sim = mp.Simulation(
+            cell_size=mp.Vector3(10, 10), resolution=10, sources=sources
+        )
         h = mp.Harminv(mp.Ez, mp.Vector3(), 1, 1)
         check_warnings(sim, h, should_warn=False)
 
     def test_vec_constructor(self):
-
         def assert_one(v):
             self.assertEqual(v.z(), 1)
 
@@ -429,14 +574,16 @@ class TestSimulation(unittest.TestCase):
             assert_two(v2)
             v3 = mp.vec(three)
             assert_three(v3)
-            assert_raises(four, (NotImplementedError,TypeError))
+            assert_raises(four, (NotImplementedError, TypeError))
 
         check_iterable([1], [1, 2], [1, 2, 3], [1, 2, 3, 4])
         check_iterable((1,), (1, 2), (1, 2, 3), (1, 2, 3, 4))
-        check_iterable(np.array([1.]),
-                       np.array([1., 2.]),
-                       np.array([1., 2., 3.]),
-                       np.array([1., 2., 3., 4.]))
+        check_iterable(
+            np.array([1.0]),
+            np.array([1.0, 2.0]),
+            np.array([1.0, 2.0, 3.0]),
+            np.array([1.0, 2.0, 3.0, 4.0]),
+        )
 
         with self.assertRaises(TypeError):
             mp.vec([1, 2], 3)
@@ -444,7 +591,9 @@ class TestSimulation(unittest.TestCase):
         with self.assertRaises(TypeError):
             mp.vec(1, [2, 3])
 
-    @unittest.skipIf(mp.is_single_precision(), "double-precision floating point specific test")
+    @unittest.skipIf(
+        mp.is_single_precision(), "double-precision floating point specific test"
+    )
     def test_epsilon_warning(self):
         ## fields blow up using dispersive material
         ## when compiled using single precision
@@ -452,9 +601,11 @@ class TestSimulation(unittest.TestCase):
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter("always")
             from meep.materials import Si
+
             self.assertEqual(len(w), 0)
 
         from meep.materials import Mo
+
         geom = [mp.Sphere(radius=0.2, material=Mo)]
         sim = self.init_simple_simulation(geometry=geom)
         with warnings.catch_warnings(record=True) as w:
@@ -464,6 +615,7 @@ class TestSimulation(unittest.TestCase):
             self.assertIn("Epsilon", str(w[0].message))
 
         from meep.materials import SiO2
+
         geom = [mp.Sphere(radius=0.2, material=SiO2)]
         sim = self.init_simple_simulation(geometry=geom)
         with warnings.catch_warnings(record=True) as w:
@@ -475,7 +627,7 @@ class TestSimulation(unittest.TestCase):
     def test_get_filename_prefix(self):
         sim = self.init_simple_simulation()
         self.assertEqual(sim.get_filename_prefix(), self.fname_base)
-        sim.filename_prefix = ''
+        sim.filename_prefix = ""
         self.assertEqual(sim.get_filename_prefix(), "")
         sim.filename_prefix = False
         with self.assertRaises(TypeError):
@@ -506,16 +658,32 @@ class TestSimulation(unittest.TestCase):
         fcen = 0.15
         df = 0.1
 
-        sources = [mp.Source(src=mp.GaussianSource(fcen, fwidth=df), component=mp.Ez,
-                             center=mp.Vector3())]
-        geometry = [mp.Block(center=mp.Vector3(), size=mp.Vector3(mp.inf, 3, mp.inf),
-                             material=mp.Medium(epsilon=12))]
+        sources = [
+            mp.Source(
+                src=mp.GaussianSource(fcen, fwidth=df),
+                component=mp.Ez,
+                center=mp.Vector3(),
+            )
+        ]
+        geometry = [
+            mp.Block(
+                center=mp.Vector3(),
+                size=mp.Vector3(mp.inf, 3, mp.inf),
+                material=mp.Medium(epsilon=12),
+            )
+        ]
 
         def print_field(sim):
             result.append(sim.get_field_point(mp.Ez, mp.Vector3(2, -1)))
 
-        sim = mp.Simulation(resolution=resolution, cell_size=cell_size, boundary_layers=pml,
-                            sources=sources, geometry=geometry, geometry_center=center)
+        sim = mp.Simulation(
+            resolution=resolution,
+            cell_size=cell_size,
+            boundary_layers=pml,
+            sources=sources,
+            geometry=geometry,
+            geometry_center=center,
+        )
         sim.run(mp.at_end(print_field), until=50)
 
         self.assertAlmostEqual(result[0], -0.0599602798684155)
@@ -529,29 +697,50 @@ class TestSimulation(unittest.TestCase):
         fcen = 0.15
         df = 0.1
 
-        sources = [mp.Source(src=mp.GaussianSource(fcen, fwidth=df), component=mp.Ez,
-                             center=mp.Vector3())]
-        geometry = [mp.Block(center=mp.Vector3(), size=mp.Vector3(mp.inf, 3, mp.inf),
-                             material=mp.Medium(epsilon=12))]
+        sources = [
+            mp.Source(
+                src=mp.GaussianSource(fcen, fwidth=df),
+                component=mp.Ez,
+                center=mp.Vector3(),
+            )
+        ]
+        geometry = [
+            mp.Block(
+                center=mp.Vector3(),
+                size=mp.Vector3(mp.inf, 3, mp.inf),
+                material=mp.Medium(epsilon=12),
+            )
+        ]
 
-        sim = mp.Simulation(resolution=resolution, cell_size=cell_size, boundary_layers=pml,
-                            sources=sources, geometry=geometry, geometry_center=center)
+        sim = mp.Simulation(
+            resolution=resolution,
+            cell_size=cell_size,
+            boundary_layers=pml,
+            sources=sources,
+            geometry=geometry,
+            geometry_center=center,
+        )
         sim.run(until=50)
         timing_data = sim.get_timing_data()
 
         # Non-exhaustive collection of steps where some time should be spent:
-        EXPECTED_NONZERO_TIMESINKS = (mp.Stepping, mp.Boundaries,
-                                      mp.FieldUpdateB, mp.FieldUpdateH,
-                                      mp.FieldUpdateD, mp.FieldUpdateE)
+        EXPECTED_NONZERO_TIMESINKS = (
+            mp.Stepping,
+            mp.Boundaries,
+            mp.FieldUpdateB,
+            mp.FieldUpdateH,
+            mp.FieldUpdateD,
+            mp.FieldUpdateE,
+        )
         # Due to the problem setup, no time should be spent on these steps:
         EXPECTED_ZERO_TIMESINKS = (mp.MPBTime, mp.GetFarfieldsTime)
 
-        for sink in itertools.chain(EXPECTED_NONZERO_TIMESINKS,
-                                    EXPECTED_ZERO_TIMESINKS):
+        for sink in itertools.chain(
+            EXPECTED_NONZERO_TIMESINKS, EXPECTED_ZERO_TIMESINKS
+        ):
             self.assertIn(sink, timing_data.keys())
             self.assertEqual(len(timing_data[sink]), mp.count_processors())
-            np.testing.assert_array_equal(sim.time_spent_on(sink),
-                                          timing_data[sink])
+            np.testing.assert_array_equal(sim.time_spent_on(sink), timing_data[sink])
 
         for sink in EXPECTED_NONZERO_TIMESINKS:
             for t in timing_data[sink]:
@@ -563,34 +752,40 @@ class TestSimulation(unittest.TestCase):
 
         self.assertGreaterEqual(
             sum(timing_data[mp.Stepping]),
-            sum(timing_data[mp.FieldUpdateB]) +
-            sum(timing_data[mp.FieldUpdateH]) +
-            sum(timing_data[mp.FieldUpdateD]) +
-            sum(timing_data[mp.FieldUpdateE]) +
-            sum(timing_data[mp.FourierTransforming]))
+            sum(timing_data[mp.FieldUpdateB])
+            + sum(timing_data[mp.FieldUpdateH])
+            + sum(timing_data[mp.FieldUpdateD])
+            + sum(timing_data[mp.FieldUpdateE])
+            + sum(timing_data[mp.FourierTransforming]),
+        )
 
     def test_source_slice(self):
         sim = self.init_simple_simulation()
         sim.run(until=1)
 
-        vol1d = mp.Volume(center=mp.Vector3(0.1234,0), size=mp.Vector3(0,5.07))
+        vol1d = mp.Volume(center=mp.Vector3(0.1234, 0), size=mp.Vector3(0, 5.07))
         source_slice = sim.get_source(mp.Ez, vol=vol1d)
-        x,y,z,w = sim.get_array_metadata(vol=vol1d)
+        x, y, z, w = sim.get_array_metadata(vol=vol1d)
         self.assertEqual(source_slice.shape, w.shape)
         self.assertEqual(np.sum(source_slice), 0)
 
-        vol2d = mp.Volume(center=mp.Vector3(-0.541,0.791), size=mp.Vector3(3.5,2.8))
+        vol2d = mp.Volume(center=mp.Vector3(-0.541, 0.791), size=mp.Vector3(3.5, 2.8))
         source_slice = sim.get_source(mp.Ez, vol=vol2d)
-        x,y,z,w = sim.get_array_metadata(vol=vol2d)
+        x, y, z, w = sim.get_array_metadata(vol=vol2d)
         self.assertEqual(source_slice.shape, w.shape)
         self.assertNotEqual(np.sum(source_slice), 0)
 
     def test_has_mu(self):
-
         def _check(med, expected, default=mp.Medium()):
-            geometry = [mp.Block(center=mp.Vector3(), size=mp.Vector3(1, 1), material=med)]
-            sim = mp.Simulation(cell_size=mp.Vector3(5, 5), resolution=10, geometry=geometry,
-                                default_material=default)
+            geometry = [
+                mp.Block(center=mp.Vector3(), size=mp.Vector3(1, 1), material=med)
+            ]
+            sim = mp.Simulation(
+                cell_size=mp.Vector3(5, 5),
+                resolution=10,
+                geometry=geometry,
+                default_material=default,
+            )
 
             result = sim.has_mu()
             if expected:
@@ -598,7 +793,7 @@ class TestSimulation(unittest.TestCase):
             else:
                 self.assertFalse(result)
 
-            print("Estimated memory usage: {}".format(sim.get_estimated_memory_usage()))
+            print(f"Estimated memory usage: {sim.get_estimated_memory_usage()}")
 
         def mat_func(p):
             return mp.Medium()
@@ -633,5 +828,6 @@ class TestSimulation(unittest.TestCase):
             self.assertAlmostEqual(pt1, expected)
             self.assertAlmostEqual(pt2, expected)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     unittest.main()
