@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008 Massachusetts Institute of Technology.
+/* Copyright (C) 2005-2022 Massachusetts Institute of Technology.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,55 +69,61 @@
 
 */
 
+using namespace std;
+
 namespace meep {
 
-#ifdef HAVE_CBLAS_DDOT
-   extern "C" double cblas_ddot(int, const double*, int, const double*, int);
-#  define dot(n, x, y) sum_to_all(cblas_ddot(n, x, 1, y, 1))
-#else
-static double dot(int n, const double *x, const double *y)
-{
+static double dot(size_t n, const realnum *x, const realnum *y) {
   double sum = 0;
-  for (int i = 0; i < n; ++i) sum += x[i] * y[i];
+  for (size_t i = 0; i < n; ++i)
+    sum += x[i] * y[i];
   return sum_to_all(sum);
 }
-#endif
 
-static double norm2(int n, const double *x) { return sqrt(dot(n, x, x)); }
-
-#if defined(HAVE_CBLAS_DAXPY)
-   extern "C" void cblas_daxpy(const int N, const double alpha, const double *X, const int incX, double *Y, const int incY);
-#  define xpay(n,x,a,y) cblas_daxpy(n, a,y,1, x,1)
-#else
-static void xpay(int n, double *x, double a, const double *y) {
-  for (int m = 0; m < n; ++m) x[m] += a * y[m];
+static double norm2(size_t n, const realnum *x) {
+  // note: we don't just do sqrt(dot(n, x, x)) in order to avoid overflow
+  size_t i;
+  double xmax = 0, scale;
+  long double sum = 0;
+  for (i = 0; i < n; ++i) {
+    double xabs = fabs(x[i]);
+    if (xabs > xmax) xmax = xabs;
+  }
+  xmax = max_to_all(xmax);
+  if (xmax == 0) return 0;
+  scale = 1.0 / xmax;
+  for (i = 0; i < n; ++i) {
+    double xs = scale * x[i];
+    sum += xs * xs;
+  }
+  return xmax * sqrt(sum_to_all(sum));
 }
-#endif
 
-#define MIN_OUTPUT_TIME 4.0 // output no more often than this many seconds
+static void xpay(size_t n, realnum *x, double a, const realnum *y) {
+  for (size_t m = 0; m < n; ++m)
+    x[m] += a * y[m];
+}
 
-typedef double *pdouble; // grr, ISO C++ forbids new (double*)[...]
+#define MEEP_MIN_OUTPUT_TIME 4.0 // output no more often than this many seconds
+
+typedef realnum *prealnum; // grr, ISO C++ forbids new (double*)[...]
 
 /* BiCGSTAB(L) algorithm for the n-by-n problem Ax = b */
-int bicgstabL(const int L, const int n, double *x,
-	      bicgstab_op A, void *Adata, const double *b,
-	      const double tol,
-	      int *iters,
-	      double *work,
-	      const bool quiet)
-{
-  if (!work) return (2*L+3)*n; // required workspace
+ptrdiff_t bicgstabL(const int L, const size_t n, realnum *x, bicgstab_op A, void *Adata,
+                    const realnum *b, const double tol, int *iters, realnum *work,
+                    const bool quiet) {
+  if (!work) return (2 * L + 3) * n; // required workspace
 
-  pdouble *r = new pdouble[L+1];
-  pdouble *u = new pdouble[L+1];
+  prealnum *r = new prealnum[L + 1];
+  prealnum *u = new prealnum[L + 1];
   for (int i = 0; i <= L; ++i) {
     r[i] = work + i * n;
-    u[i] = work + (L+1 + i) * n;
+    u[i] = work + (L + 1 + i) * n;
   }
 
   double bnrm = norm2(n, b);
   if (bnrm == 0.0) bnrm = 1.0;
-  
+
   int iter = 0;
   double last_output_wall_time = wall_time();
 
@@ -134,65 +140,71 @@ int bicgstabL(const int L, const int n, double *x,
   /**** FIXME: check for breakdown conditions(?) during iteration  ****/
 
   // rtilde = r[0] = b - Ax
-  double *rtilde = work + (2*L+2) * n;
+  realnum *rtilde = work + (2 * L + 2) * n;
   A(x, r[0], Adata);
-  for (int m = 0; m < n; ++m) rtilde[m] = r[0][m] = b[m] - r[0][m];
+  for (size_t m = 0; m < n; ++m)
+    rtilde[m] = r[0][m] = b[m] - r[0][m];
 
   { /* Sleipjen normalizes rtilde in his code; it seems to help slightly */
     double s = 1.0 / norm2(n, rtilde);
-    for (int m = 0; m < n; ++m) rtilde[m] *= s;
+    for (size_t m = 0; m < n; ++m)
+      rtilde[m] *= s;
   }
 
-  memset(u[0], 0, sizeof(double) * n); // u[0] = 0
+  memset(u[0], 0, sizeof(realnum) * n); // u[0] = 0
 
   double rho = 1.0, alpha = 0, omega = 1;
 
   double resid;
   while ((resid = norm2(n, r[0])) > tol * bnrm) {
     ++iter;
-    if (!quiet && wall_time() > last_output_wall_time + MIN_OUTPUT_TIME) {
+    if (!quiet && wall_time() > last_output_wall_time + MEEP_MIN_OUTPUT_TIME) {
       master_printf("residual[%d] = %g\n", iter, resid / bnrm);
       last_output_wall_time = wall_time();
     }
 
     rho = -omega * rho;
     for (int j = 0; j < L; ++j) {
-      if (fabs(rho) < breaktol) { ierr = -1; goto finish; }
+      if (fabs(rho) < breaktol) {
+        ierr = -1;
+        goto finish;
+      }
       double rho1 = dot(n, r[j], rtilde);
       double beta = alpha * rho1 / rho;
       rho = rho1;
       for (int i = 0; i <= j; ++i)
-	for (int m = 0; m < n; ++m) u[i][m] = r[i][m] - beta * u[i][m];
-      A(u[j], u[j+1], Adata);
-      alpha = rho / dot(n, u[j+1], rtilde);
+        for (size_t m = 0; m < n; ++m)
+          u[i][m] = r[i][m] - beta * u[i][m];
+      A(u[j], u[j + 1], Adata);
+      alpha = rho / dot(n, u[j + 1], rtilde);
       for (int i = 0; i <= j; ++i)
-	xpay(n, r[i], -alpha, u[i+1]);
-      A(r[j], r[j+1], Adata);
+        xpay(n, r[i], -alpha, u[i + 1]);
+      A(r[j], r[j + 1], Adata);
       xpay(n, x, alpha, u[0]);
     }
 
     for (int j = 1; j <= L; ++j) {
       for (int i = 1; i < j; ++i) {
-	int ij = (j-1)*L + (i-1);
-	tau[ij] = dot(n, r[j], r[i]) / sigma[i];
-	xpay(n, r[j], -tau[ij], r[i]);
+        int ij = (j - 1) * L + (i - 1);
+        tau[ij] = dot(n, r[j], r[i]) / sigma[i];
+        xpay(n, r[j], -tau[ij], r[i]);
       }
-      sigma[j] = dot(n, r[j],r[j]);
+      sigma[j] = dot(n, r[j], r[j]);
       gamma_p[j] = dot(n, r[0], r[j]) / sigma[j];
     }
 
     omega = gamma[L] = gamma_p[L];
-    for (int j = L-1; j >= 1; --j) {
+    for (int j = L - 1; j >= 1; --j) {
       gamma[j] = gamma_p[j];
-      for (int i = j+1; i <= L; ++i)
-	gamma[j] -= tau[(i-1)*L + (j-1)] * gamma[i];
+      for (int i = j + 1; i <= L; ++i)
+        gamma[j] -= tau[(i - 1) * L + (j - 1)] * gamma[i];
     }
     for (int j = 1; j < L; ++j) {
-      gamma_pp[j] = gamma[j+1];
-      for (int i = j+1; i < L; ++i)
-	gamma_pp[j] += tau[(i-1)*L + (j-1)] * gamma[i+1];
+      gamma_pp[j] = gamma[j + 1];
+      for (int i = j + 1; i < L; ++i)
+        gamma_pp[j] += tau[(i - 1) * L + (j - 1)] * gamma[i + 1];
     }
-    
+
     xpay(n, x, gamma[1], r[0]);
     xpay(n, r[0], -gamma_p[L], r[L]);
     xpay(n, u[0], -gamma[L], u[L]);
@@ -202,12 +214,15 @@ int bicgstabL(const int L, const int n, double *x,
       xpay(n, u[0], -gamma[j], u[j]);
     }
 
-    if (iter == *iters) { ierr = 1; break; }
+    if (iter == *iters) {
+      ierr = 1;
+      break;
+    }
   }
 
   if (!quiet) master_printf("final residual = %g\n", norm2(n, r[0]) / bnrm);
 
- finish:
+finish:
   delete[] sigma;
   delete[] tau;
   delete[] gamma_pp;
