@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2021 Massachusetts Institute of Technology.
+/* Copyright (C) 2005-2022 Massachusetts Institute of Technology.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ struct integrate_data {
   const component *components2;
   component *cS;
   complex<double> *ph;
-  complex<double> *fvals;
+  complex<realnum> *fvals;
   ptrdiff_t *offsets;
   int ninveps;
   component inveps_cs[3];
@@ -43,7 +43,7 @@ struct integrate_data {
   int ninvmu;
   component invmu_cs[3];
   direction invmu_ds[3];
-  complex<long double> sum;
+  complex<double> sum;
   double maxabs;
   field_function integrand;
   void *integrand_data_;
@@ -57,7 +57,8 @@ static void integrate_chunkloop(fields_chunk *fc, int ichunk, component cgrid, i
   integrate_data *data = (integrate_data *)data_;
   ptrdiff_t *off = data->offsets;
   component *cS = data->cS;
-  complex<double> *fvals = data->fvals, *ph = data->ph;
+  complex<realnum> *fvals = data->fvals;
+  complex<double> *ph = data->ph;
   complex<long double> sum = 0.0;
   double maxabs = 0;
   const component *iecs = data->inveps_cs;
@@ -177,11 +178,11 @@ static void integrate_chunkloop(fields_chunk *fc, int ichunk, component cgrid, i
     }
 
     complex<double> integrand = data->integrand(fvals, loc, data->integrand_data_);
-    maxabs = max(maxabs, abs(integrand));
+    maxabs = std::max(maxabs, abs(integrand));
     sum += integrand * IVEC_LOOP_WEIGHT(s0, s1, e0, e1, dV0 + dV1 * loop_i2);
   }
 
-  data->maxabs = max(data->maxabs, maxabs);
+  data->maxabs = std::max(data->maxabs, maxabs);
   data->sum += sum;
 }
 
@@ -190,7 +191,7 @@ complex<double> fields::integrate2(const fields &fields2, int num_fvals1,
                                    const component *components2, field_function integrand,
                                    void *integrand_data_, const volume &where, double *maxabs) {
   if (!equal_layout(fields2))
-    abort("invalid call to integrate2: fields must have equal grid layout");
+    meep::abort("invalid call to integrate2: fields must have equal grid layout");
 
   if (num_fvals2 == 0)
     return integrate(num_fvals1, components1, integrand, integrand_data_, where, maxabs);
@@ -223,7 +224,7 @@ complex<double> fields::integrate2(const fields &fields2, int num_fvals1,
   data.components2 = components2;
   data.cS = new component[num_fvals1 + num_fvals2];
   data.ph = new complex<double>[num_fvals1 + num_fvals2];
-  data.fvals = new complex<double>[num_fvals1 + num_fvals2];
+  data.fvals = new complex<realnum>[num_fvals1 + num_fvals2];
   data.sum = 0;
   data.maxabs = 0;
   data.integrand = integrand;
@@ -244,7 +245,7 @@ complex<double> fields::integrate2(const fields &fields2, int num_fvals1,
         break;
       }
   if (needs_dielectric) FOR_ELECTRIC_COMPONENTS(c) if (gv.has_field(c)) {
-      if (data.ninveps == 3) abort("more than 3 field components??");
+      if (data.ninveps == 3) meep::abort("more than 3 field components??");
       data.inveps_cs[data.ninveps] = c;
       data.inveps_ds[data.ninveps] = component_direction(c);
       ++data.ninveps;
@@ -265,7 +266,7 @@ complex<double> fields::integrate2(const fields &fields2, int num_fvals1,
         break;
       }
   if (needs_permeability) FOR_MAGNETIC_COMPONENTS(c) if (gv.has_field(c)) {
-      if (data.ninvmu == 3) abort("more than 3 field components??");
+      if (data.ninvmu == 3) meep::abort("more than 3 field components??");
       data.invmu_cs[data.ninvmu] = c;
       data.invmu_ds[data.ninvmu] = component_direction(c);
       ++data.ninvmu;
@@ -285,14 +286,15 @@ complex<double> fields::integrate2(const fields &fields2, int num_fvals1,
   if (maxabs) *maxabs = max_to_all(data.maxabs);
   data.sum = sum_to_all(data.sum);
 
-  return complex<double>(real(data.sum), imag(data.sum));
+  return cdouble(data.sum);
 }
 
 typedef struct {
   field_rfunction integrand;
   void *integrand_data;
 } rfun_wrap_data;
-static complex<double> rfun_wrap(const complex<double> *fields, const vec &loc, void *data_) {
+
+static complex<double> rfun_wrap(const complex<realnum> *fields, const vec &loc, void *data_) {
   rfun_wrap_data *data = (rfun_wrap_data *)data_;
   return data->integrand(fields, loc, data->integrand_data);
 }
