@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2021 Massachusetts Institute of Technology
+/* Copyright (C) 2005-2022 Massachusetts Institute of Technology
 %
 %  This program is free software; you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ FILE *create_output_file(const char *dirname, const char *fname) {
   char n[buflen];
   snprintf(n, buflen, "%s/%s", dirname, fname);
   FILE *o = master_fopen(n, "w");
-  if (!o) abort("Unable to create file %s!\n", n);
+  if (!o) meep::abort("Unable to create file %s!\n", n);
   return o;
 }
 
@@ -109,9 +109,7 @@ const char *make_output_directory(const char *exename, const char *jobname) {
   snprintf(sourcename, buflen, "%s.cpp", stripped_name);
 
   if (jobname != NULL) { snprintf(basename, buflen, "%s", jobname); }
-  else {
-    snprintf(basename, buflen, "%s", stripped_name);
-  }
+  else { snprintf(basename, buflen, "%s", stripped_name); }
 
   static char outdirname[buflen];
   snprintf(outdirname, buflen, "%s-out", basename);
@@ -151,7 +149,7 @@ got_tmpdir:
   strcat(strcpy(outdirname, tmpdir), meeptemplate);
 
   if (am_master() && !mkdtemp(outdirname)) {
-    abort("failed to create temporary output directory \"%s\"", outdirname);
+    meep::abort("failed to create temporary output directory \"%s\"", outdirname);
   }
   broadcast(0, outdirname, len);
   return outdirname;
