@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2021 Massachusetts Institute of Technology
+/* Copyright (C) 2005-2022 Massachusetts Institute of Technology
 %
 %  This program is free software; you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -43,11 +43,9 @@ double rods(const vec &r) {
 void compare(double b, double a, const char *n) {
   double thresh = sizeof(realnum) == sizeof(float) ? 1e-4 : 1e-5;
   if (fabs(a - b) > fabs(b) * thresh || b != b) {
-    abort("Failed %s (%g instead of %g, relerr %0.2g)\n", n, a, b, fabs(a - b) / fabs(b));
-  }
-  else {
-    master_printf("Passed %s\n", n);
+    meep::abort("Failed %s (%g instead of %g, relerr %0.2g)\n", n, a, b, fabs(a - b) / fabs(b));
   }
+  else { master_printf("Passed %s\n", n); }
 }
 
 static double dpml = 1.0;
